@@ -15,15 +15,15 @@
  */
 
 
+#ifndef BSON_UTF8_H
+#define BSON_UTF8_H
+
+
 #if !defined (BSON_INSIDE) && !defined (BSON_COMPILATION)
 # error "Only <bson.h> can be included directly."
 #endif
 
 
-#ifndef BSON_UTF8_H
-#define BSON_UTF8_H
-
-
 #include "bson-macros.h"
 #include "bson-types.h"
 
@@ -34,8 +34,6 @@ BSON_BEGIN_DECLS
 bool            bson_utf8_validate        (const char     *utf8,
                                            size_t          utf8_len,
                                            bool            allow_null);
-char           *bson_utf8_escape_for_json (const char     *utf8,
-                                           ssize_t         utf8_len);
 bson_unichar_t  bson_utf8_get_char        (const char     *utf8);
 const char     *bson_utf8_next_char       (const char     *utf8);
 void            bson_utf8_from_unichar    (bson_unichar_t  unichar,
