@@ -19,7 +19,7 @@ package MongoDB::InsertManyResult;
 # ABSTRACT: MongoDB single insert result object
 
 use version;
-our $VERSION = 'v1.2.1';
+our $VERSION = 'v1.2.3';
 
 use Moo;
 use MongoDB::_Constants;
@@ -44,11 +44,17 @@ with $_ for qw(
 #pod =cut
 
 has inserted_count => (
-    is      => 'ro',
-    default => 0,
+    is      => 'lazy',
+    builder => '_build_inserted_count',
     isa => Num,
 );
 
+sub _build_inserted_count
+{
+    my ($self) = @_;
+    return scalar @{ $self->inserted };
+}
+
 #pod =attr inserted
 #pod
 #pod An array reference containing information about inserted documents (if any).
@@ -94,7 +100,7 @@ MongoDB::InsertManyResult - MongoDB single insert result object
 
 =head1 VERSION
 
-version v1.2.1
+version v1.2.3
 
 =head1 SYNOPSIS
 
@@ -170,7 +176,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by MongoDB, Inc..
+This software is Copyright (c) 2016 by MongoDB, Inc..
 
 This is free software, licensed under:
 
