@@ -29,10 +29,15 @@ use version;
 
 our @EXPORT_OK = qw(
   build_client get_test_db server_version server_type clear_testdbs get_capped
+  skip_unless_mongod
 );
 
 my @testdbs;
 
+sub _check_local_rs {
+
+}
+
 # abstract building a connection
 sub build_client {
     my %args = @_;
@@ -46,9 +51,8 @@ sub build_client {
         $host,
         {
             ssl                         => $ENV{MONGO_SSL},
-            find_master                 => 1,
-            query_timeout               => 60000,
-            server_selection_timeout_ms => 1000,
+            socket_timeout_ms           => 60000,
+            server_selection_timeout_ms => 2000,
             %args,
         }
     );
@@ -71,32 +75,39 @@ sub get_capped {
     return $db->get_collection($name);
 }
 
-# XXX eventually, should move away from this and towards a fixture object instead
-BEGIN {
+sub skip_unless_mongod {
     eval {
         my $conn = build_client( server_selection_timeout_ms => 1000 );
-        $conn->_topology->scan_all_servers;
-        $conn->_topology->_dump;
-        eval { $conn->_topology->get_writable_link }
-            or die "couldn't connect";
-        $conn->get_database("admin")->run_command({ serverStatus => 1 })
-            or die "Database has auth enabled\n";
+        my $topo = $conn->_topology;
+        $topo->scan_all_servers;
+        my $link;
+        eval { $link = $topo->get_writable_link }
+          or die "couldn't connect";
+        $conn->get_database("admin")->run_command( { serverStatus => 1 } )
+          or die "Database has auth enabled\n";
+        my $server = $link->server;
+        if ( !$ENV{MONGOD} && $topo->type eq 'Single' && $server->type =~ /^RS/ ) {
+            # direct connection to RS member on default, so add set name
+            # via MONGOD environment variable for subsequent use
+            $ENV{MONGOD} = "mongodb://localhost/?replicaSet=" . $server->set_name;
+        }
+##        $conn->_topology->_dump;
     };
 
-    if ( $@ ) {
-        (my $err = $@) =~ s/\n//g;
+    if ($@) {
+        ( my $err = $@ ) =~ s/\n//g;
         if ( $err =~ /couldn't connect|connection refused/i ) {
-            $err = "no mongod on " . ($ENV{MONGOD} || "localhost:27017");
+            $err = "no mongod on " . ( $ENV{MONGOD} || "localhost:27017" );
             $err .= ' and $ENV{MONGOD} not set' unless $ENV{MONGOD};
         }
         plan skip_all => "$err";
     }
-};
+}
 
 sub server_version {
 
     my $conn = shift;
-    my $build = $conn->get_database( 'admin' )->get_collection( '$cmd' )->find_one( { buildInfo => 1 } );
+    my $build = $conn->send_admin_command( [ buildInfo => 1 ] )->output;
     my ($version_str) = $build->{version} =~ m{^([0-9.]+)};
     return version->parse("v$version_str");
 }
